==> rofi_1.5.1.orig.tar.gz: rofi-1.5.1/subprojects/libnkutils/src/uuid-apr-util.c <==
/*
 * libnkutils/uuid - Miscellaneous utilities, uuid module
 *
 * Copyright © 2011-2017 Quentin "Sardem FF7" Glidic
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif /* HAVE_CONFIG_H */

#ifdef G_LOG_DOMAIN
#undef G_LOG_DOMAIN
#endif /* G_LOG_DOMAIN */
#define G_LOG_DOMAIN "libnkutils-uuid"

#include <string.h>

#include <glib.h>
#include <apr_uuid.h>

#include "nkutils-uuid.h"
#include "uuid-internal.h"

void
nk_uuid_update_string(NkUuid *self)
{
    apr_uuid_format(self->string, (apr_uuid_t *) self);
}

void
nk_uuid_generate(NkUuid *self)
{
    apr_uuid_get((apr_uuid_t *) self);
    nk_uuid_update_string(self);
}

gboolean
nk_uuid_parse(NkUuid *self, const gchar *string)
{
    if ( apr_uuid_parse((apr_uuid_t *) self, string) < 0 )
        return FALSE;

    nk_uuid_update_string(self);
    return TRUE;
}

==> rofi_1.7.5.orig.tar.gz: rofi-1.7.5/subprojects/libnkutils/src/uuid-apr-util.c <==
/*
 * libnkutils/uuid - Miscellaneous utilities, uuid module
 *
 * Copyright © 2011-2017 Quentin "Sardem FF7" Glidic
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif /* HAVE_CONFIG_H */

#ifdef G_LOG_DOMAIN
#undef G_LOG_DOMAIN
#endif /* G_LOG_DOMAIN */
#define G_LOG_DOMAIN "libnkutils-uuid"

#include <string.h>

#include <glib.h>
#include <apr_uuid.h>

#include "nkutils-uuid.h"
#include "uuid-internal.h"

void
nk_uuid_update_string(NkUuid *self)
{
    apr_uuid_format(self->string, (apr_uuid_t *) self);
}

void
nk_uuid_generate(NkUuid *self)
{
    apr_uuid_get((apr_uuid_t *) self);
    nk_uuid_update_string(self);
}

gboolean
nk_uuid_parse(NkUuid *self, const gchar *string)
{
    if ( apr_uuid_parse((apr_uuid_t *) self, string) != APR_SUCCESS )
        return FALSE;

    nk_uuid_update_string(self);
    return TRUE;
}
